<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'access_interface_graphique' => 'Возврат к полному интерфейсу',
	'access_mode_texte' => 'Упрощенный текстовый интерфейс',
	'admin_debug' => 'Отладка',
	'admin_modifier_article' => 'Изменить статью',
	'admin_modifier_auteur' => 'Изменить автора',
	'admin_modifier_breve' => 'Изменить новость',
	'admin_modifier_mot' => 'Изменить ключ',
	'admin_modifier_rubrique' => 'Изменить раздел',
	'admin_recalculer' => 'Обновить страницу',
	'afficher_calendrier' => 'Показать календарь',
	'afficher_trad' => 'показать переводы',
	'alerte_maj_impossible' => '<b>Внимание!</b> Не удалось обновить базу SQL до версии @version@.  Возможно, неправильно указаны параметры доступа к базе.',
	'alerte_modif_info_concourante' => 'Внимание: Эта страница редактируется еще кем-то на сайте. Текущее значение :',
	'analyse_xml' => 'XML парсинг',
	'annuler' => 'Отмена',
	'antispam_champ_vide' => 'Оставьте это поле пустым:',
	'articles_recents' => 'Свежие статьи',
	'avis_1_erreur_saisie' => 'Имеется 1 ошибка в записи, проверьте информацию.',
	'avis_archive_incorrect' => 'это неправильный архивный файл SPIP',
	'avis_archive_invalide' => 'этот архивный файл не может быть использован',
	'avis_attention' => 'Внимание!',
	'avis_champ_incorrect_type_objet' => 'Неправильное поле @name@ для объекта типа @type@',
	'avis_colonne_inexistante' => 'Колонка @col@ не существует',
	'avis_erreur' => 'Ошибка: см. ниже',
	'avis_erreur_connexion' => 'Ошибка соединения',
	'avis_erreur_cookie' => 'проблема с cookie ',
	'avis_erreur_fonction_contexte' => 'Ошибка программы. Эту функцию нельзя вызывать в этом контексте.',
	'avis_erreur_mysql' => 'Ошибка SQL ',
	'avis_erreur_sauvegarde' => 'Ошибка в бэкапе (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Ошибка при входе в администрирование сайта',
	'avis_nb_erreurs_saisie' => 'Обнаружено @nb@ ошибок в вашей записи, проверьте информацию.',

	// B
	'barre_a_accent_grave' => 'Прописное A с пимпочкой вверху',
	'barre_aide' => 'Используйте кнопки для быстрого форматирования текста',
	'barre_e_accent_aigu' => 'Прописное E, acute accent',
	'barre_eo' => 'Вставить дифтонг oe',
	'barre_eo_maj' => 'Вставить дифтонг EO',
	'barre_euro' => 'Вставить символ € (евро)',
	'barre_gras' => 'Выделить {{полужирным}}',
	'barre_guillemets' => 'Разместить между “двойными кавычками”',
	'barre_guillemets_simples' => 'Разместить между ‘одинарными кавычками’',
	'barre_intertitre' => '{{{Подзаголовок}}}',
	'barre_italic' => 'Выделить {курсивом}',
	'barre_lien' => 'Поставить ссылку [ссылка->http://...]',
	'barre_lien_input' => 'Пожалуйста, введите объект, на который указывает гиперссылка (можно указать URL по типу http://www.mysite.com или просто номер одной из статей этого сайта).',
	'barre_note' => 'Добавить [[Сноску]]',
	'barre_paragraphe' => 'Абзац',
	'barre_quote' => '<quote>Цитирование</quote>',
	'bouton_changer' => 'Изменить',
	'bouton_chercher' => 'Поиск',
	'bouton_choisir' => 'Выбрать',
	'bouton_deplacer' => 'Переместить',
	'bouton_download' => 'Скачать',
	'bouton_enregistrer' => 'Сохранить',
	'bouton_radio_desactiver_messagerie_interne' => 'Отключить приватную переписку',
	'bouton_radio_envoi_annonces' => 'Отправить оповещение',
	'bouton_radio_non_envoi_annonces' => 'Отключить отправку внутренних сообщений',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Не отправлять список последних новостей',
	'bouton_recharger_page' => 'перезагрузить страницу',
	'bouton_telecharger' => 'Загрузить',
	'bouton_upload' => 'Загрузить',
	'bouton_valider' => 'Отправить',

	// C
	'cal_apresmidi' => 'вторая половина дня (p.m.)',
	'cal_jour_entier' => 'весь день',
	'cal_matin' => 'утро (a.m.)',
	'cal_par_jour' => 'календарь - день',
	'cal_par_mois' => 'календарь - месяц',
	'cal_par_semaine' => 'календарь - неделя',
	'choix_couleur_interface' => 'цвет',
	'choix_interface' => 'выбор интерфейса',
	'colonne' => 'Колонка',
	'confirm_changer_statut' => 'Внимание: вы измените статус статьи. Изменить?',
	'correcte' => 'исправить',

	// D
	'date_aujourdhui' => 'сегодня',
	'date_avant_jc' => 'до н.э.',
	'date_dans' => 'в @delai@',
	'date_de_mois_1' => '@j@ января',
	'date_de_mois_10' => '@j@ октября',
	'date_de_mois_11' => '@j@ ноября',
	'date_de_mois_12' => '@j@ декабря',
	'date_de_mois_2' => '@j@ февраля',
	'date_de_mois_3' => '@j@ марта',
	'date_de_mois_4' => '@j@ апреля',
	'date_de_mois_5' => '@j@ мая',
	'date_de_mois_6' => '@j@ июня',
	'date_de_mois_7' => '@j@ июля',
	'date_de_mois_8' => '@j@ августа',
	'date_de_mois_9' => '@j@ сентября',
	'date_demain' => 'завтра',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_heures_minutes_court' => '@h@:@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ в @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ с @heure_debut@ до @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ с @heure_debut@@dtabbr@ до @dtstart@@heure_fin@@dtend@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'от @nomjour@ @date@',
	'date_fmt_periode' => 'С @date_debut@ до @date_fin@',
	'date_fmt_periode_abbr' => 'С @dtart@@date_debut@@dtabbr@ до @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'С',
	'date_fmt_periode_to' => 'до',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'час',
	'date_hier' => 'вчера',
	'date_il_y_a' => '@delai@ назад',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'воскресенье',
	'date_jour_1_abbr' => 'Вос.',
	'date_jour_1_initiale' => 'В.',
	'date_jour_2' => 'понедельник',
	'date_jour_2_abbr' => 'Пон.',
	'date_jour_2_initiale' => 'П.',
	'date_jour_3' => 'вторник',
	'date_jour_3_abbr' => 'Вто.',
	'date_jour_3_initiale' => 'В.',
	'date_jour_4' => 'среда',
	'date_jour_4_abbr' => 'Сре.',
	'date_jour_4_initiale' => 'С.',
	'date_jour_5' => 'четверг',
	'date_jour_5_abbr' => 'Чет.',
	'date_jour_5_initiale' => 'Ч.',
	'date_jour_6' => 'пятница',
	'date_jour_6_abbr' => 'Пят.',
	'date_jour_6_initiale' => 'П.',
	'date_jour_7' => 'суббота',
	'date_jour_7_abbr' => 'Суб.',
	'date_jour_7_initiale' => 'С.',
	'date_jours' => 'день',
	'date_minutes' => 'минуты',
	'date_mois' => 'месяцы',
	'date_mois_1' => 'Январь',
	'date_mois_10' => 'Октябрь',
	'date_mois_10_abbr' => 'Окт',
	'date_mois_11' => 'Ноябрь',
	'date_mois_11_abbr' => 'Ноя',
	'date_mois_12' => 'Декабрь',
	'date_mois_12_abbr' => 'Дек',
	'date_mois_1_abbr' => 'Янв',
	'date_mois_2' => 'Февраль',
	'date_mois_2_abbr' => 'Фев',
	'date_mois_3' => 'Март',
	'date_mois_3_abbr' => 'Мар',
	'date_mois_4' => 'Апрель',
	'date_mois_4_abbr' => 'Апр',
	'date_mois_5' => 'Май',
	'date_mois_5_abbr' => 'Май',
	'date_mois_6' => 'Июнь',
	'date_mois_6_abbr' => 'Июн',
	'date_mois_7' => 'Июль',
	'date_mois_7_abbr' => 'Июл',
	'date_mois_8' => 'Август',
	'date_mois_8_abbr' => 'Авг',
	'date_mois_9' => 'Сентябрь',
	'date_mois_9_abbr' => 'Сен',
	'date_saison_1' => 'зима',
	'date_saison_2' => 'весна',
	'date_saison_3' => 'лето',
	'date_saison_4' => 'осень',
	'date_secondes' => 'секунд',
	'date_semaines' => 'недели',
	'date_un_mois' => 'месяц',
	'date_une_heure' => 'час(ов)',
	'date_une_minute' => 'минут(а)',
	'date_une_seconde' => 'секунда',
	'date_une_semaine' => 'неделя',
	'dirs_commencer' => 'для того, чтобы начать установку',
	'dirs_preliminaire' => 'Подготовка: <b>Настройки прав доступа</b>',
	'dirs_probleme_droits' => 'Проблема в правах доступа',
	'dirs_repertoires_absents' => '<b>Следующие папки не найдены:<ul>@bad_dirs@.</ul></b>
  <p>Возможная причина - использование строчных и прописных букв в названии папок. Пожалуйста, проверьте соответствие регистра букв в названиях папок тому, что выводится выше; если есть несовпадения, переименуйте папки используя FTP-клиент, чтобы исправить ошибку.
 </p><p>Как только это будет сделано, всё заработает</p>',
	'dirs_repertoires_suivants' => '<b>У следующих папок нет прав на запись:
<ul>@bad_dirs@.</ul></b>

  <p>Для изменений прав доступа воспользуйтесь FTP клиентом и задайте права "777" или "ххх-ххх-ххх".
</p>

',
	'double_occurrence' => 'Тег @balise@ встречается дважды',

	// E
	'en_cours' => 'выполняется',
	'envoi_via_le_site' => 'Отправить при помощи сайта',
	'erreur' => 'Ошибка',
	'erreur_balise_non_fermee' => 'последний тег не закрыт:',
	'erreur_technique_ajaxform' => 'Непонятная ошибка не дает отправить эту форму. Попробуйте еще раз.',
	'erreur_technique_enregistrement_champs' => 'Из-за технической ошибки не удалось правильно зарегистрировать поле @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Не удается зарегистрировать из-за технической ошибки.',
	'erreur_texte' => 'Ошибка(и)',
	'etape' => 'Этап',

	// F
	'fichier_introuvable' => 'Файл не найден: @fichier@', # MODIF
	'form_auteur_confirmation' => 'Пожалуйста, подтвердите ваш email',
	'form_auteur_email_modifie' => 'Ваш email был изменен.',
	'form_auteur_envoi_mail_confirmation' => 'Письмо о подтверждении было отправлено по адресу @email@. Вам необходимо будет перейти по ссылке в письме, чтобы подтвердить свой почтовый адрес.',
	'form_auteur_mail_confirmation' => 'Добрый день,

Вы запросили смену вашего почтового адреса.
Чтобы подтвердить ваш новый адрес перейдите по ссылке:
    @url@
 (Если вы этого не сделаете, то адрес не изменится):

',
	'form_deja_inscrit' => 'Вы уже зарегистрированы.',
	'form_email_non_valide' => 'Указан неправильный e-mail адрес.',
	'form_forum_access_refuse' => 'У вас больше нет доступа к этому сайту.',
	'form_forum_bonjour' => 'Приветствуем @nom@,',
	'form_forum_confirmer_email' => 'Для подтверждения регистрации на сайте перейдите по ссылке: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Этот адрес электронной почты уже зарегистрирован. Попробуйте использовать ваш обычный пароль.',
	'form_forum_identifiant_mail' => 'Информация о параметрах входа на сайт была отправлена на вашу почту.',
	'form_forum_identifiants' => 'Параметры входа на сайт',
	'form_forum_indiquer_nom_email' => 'Введите ваше имя и адрес электронной почты. Вы получите параметры доступа к сайту по электронной почте.',
	'form_forum_login' => 'логин:',
	'form_forum_message_auto' => '(это автоматическое сообщение)',
	'form_forum_pass' => 'пароль:',
	'form_forum_probleme_mail' => 'Ошибка почты: не удалось выслать идентификатор.',
	'form_forum_voici1' => 'Данные для доступа к сайту
«@nom_site_spip@» (@adresse_site@):',
	'form_forum_voici2' => 'Данные для доступа на сайт 
(возможность отправлять свои статьи) «@nom_site_spip@»
(@adresse_login@):',
	'form_indiquer_email' => 'Пожалуйста, укажите ваш e-mail.',
	'form_indiquer_nom' => 'Введите ваше имя.',
	'form_indiquer_nom_site' => 'Пожалуйста, введите название вашего сайта.',
	'form_pet_deja_enregistre' => 'Этот сайт уже зарегистрирован',
	'form_pet_signature_pasprise' => 'Ваша подпись проигнорирована.',
	'form_prop_confirmer_envoi' => 'Подтвердить отправку',
	'form_prop_description' => 'Описание/комментарий',
	'form_prop_enregistre' => 'Ваше предложение было записано и будет online после подтверждения администраторами сайта.',
	'form_prop_envoyer' => 'Отправить сообщение',
	'form_prop_indiquer_email' => 'Пожалуйста, укажите корректный e-mail ',
	'form_prop_indiquer_nom_site' => 'Укажите название сайта.',
	'form_prop_indiquer_sujet' => 'Укажите тему',
	'form_prop_message_envoye' => 'Сообщение отправлено',
	'form_prop_non_enregistre' => 'Ваше предложение не было записано.',
	'form_prop_sujet' => 'Тема',
	'form_prop_url_site' => 'URL сайта',
	'forum_non_inscrit' => 'Либо вы не зарегистрированы, либо адрес или пароль неправильны.',
	'forum_par_auteur' => ' @auteur@',
	'forum_titre_erreur' => 'Ошибка...',

	// I
	'ical_texte_rss_articles' => 'RSS лента сайта:',
	'ical_texte_rss_articles2' => 'RSS разделов сайта:',
	'ical_texte_rss_breves' => 'Еще есть файл, содержащий новости сайта. Выбирая разные рубрики, вы можете получать новости только из них.',
	'icone_a_suivre' => 'Панель управления',
	'icone_admin_site' => 'Администратор сайта',
	'icone_agenda' => 'Календарь',
	'icone_aide_ligne' => 'Помощь',
	'icone_articles' => 'Статьи',
	'icone_auteurs' => 'Авторы',
	'icone_brouteur' => 'Быстрый переход',
	'icone_configuration_site' => 'Настройка',
	'icone_configurer_site' => 'Настройте ваш сайт',
	'icone_creer_nouvel_auteur' => 'Новый автор',
	'icone_creer_rubrique' => 'Новый раздел',
	'icone_creer_sous_rubrique' => 'Новый подраздел',
	'icone_deconnecter' => 'Выйти',
	'icone_discussions' => 'Обсуждения',
	'icone_doc_rubrique' => 'Приложенные документы',
	'icone_ecrire_article' => 'Новая статья',
	'icone_edition_site' => 'Изменить сайт',
	'icone_gestion_langues' => 'Языковые настройки',
	'icone_informations_personnelles' => 'Персональная информация',
	'icone_interface_complet' => 'Полный интерфейс',
	'icone_interface_simple' => 'Упрощенный интерфейс',
	'icone_maintenance_site' => 'Обслуживание сайта',
	'icone_messagerie_personnelle' => 'Личные сообщения',
	'icone_repartition_debut' => 'Распределение показов с начала',
	'icone_rubriques' => 'Разделы',
	'icone_sauver_site' => 'Резервная копия сайта',
	'icone_site_entier' => 'Весь сайт',
	'icone_sites_references' => 'Каталог сайтов',
	'icone_statistiques' => 'Статистика сайта',
	'icone_suivi_activite' => 'RSS и iCal',
	'icone_suivi_actualite' => 'Статистика сайта',
	'icone_suivi_pettions' => 'Отслеживание/управление петициями',
	'icone_suivi_revisions' => 'Версии статьи',
	'icone_supprimer_document' => 'Удалить документ',
	'icone_supprimer_image' => 'Удалить изображение',
	'icone_tous_articles' => 'Ваши статьи',
	'icone_tous_auteur' => 'Все авторы',
	'icone_tous_visiteur' => 'Все посетили',
	'icone_visiter_site' => 'Посетить сайт',
	'icone_voir_en_ligne' => 'Смотреть online',
	'img_indisponible' => 'изображение недоступно',
	'impossible' => 'невозможно',
	'info_a_suivre' => 'ПАНЕЛЬ УПРАВЛЕНИЯ',
	'info_acces_interdit' => 'Доступ запрещен',
	'info_acces_refuse' => 'Доступ запрещен',
	'info_action' => 'Действие: @action@',
	'info_administrer_rubriques' => 'Вы можете управлять этим разделом и  подразделами',
	'info_adresse_non_indiquee' => 'Не указан адрес для проверки!',
	'info_aide' => 'ПОМОЩЬ:',
	'info_ajouter_mot' => 'Добавить ключ',
	'info_annonce' => 'ОБЪЯВЛЕНИЕ',
	'info_annonces_generales' => 'Общие объявления:',
	'info_article_propose' => 'Статья отправлена',
	'info_article_publie' => 'Статья опубликована',
	'info_article_redaction' => 'Статья не опубликована',
	'info_article_refuse' => 'Статья отклонена',
	'info_article_supprime' => 'Статья удалена',
	'info_articles' => 'Статьи',
	'info_articles_a_valider' => 'Статьи для утверждения',
	'info_articles_nb' => '@nb@ статей',
	'info_articles_proposes' => 'Отправленные статьи',
	'info_articles_un' => '1 статья',
	'info_auteurs_nombre' => 'автор(а):',
	'info_authentification_ftp' => 'FTP авторизация.',
	'info_breves_2' => 'новости',
	'info_breves_nb' => '@nb@ новостей',
	'info_breves_un' => '1 новость',
	'info_connexion_refusee' => 'Подключение запрещено',
	'info_contact_developpeur' => 'Свяжитесь с разработчиками.',
	'info_contenance' => 'Этот сайт содержит:',
	'info_contribution' => 'вложения в форум',
	'info_copyright' => '@spip@ - это бесплатное программное обеспечение, распространяемое @lien_gpl@.',
	'info_copyright_doc' => 'Больше информации о SPIP <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'под лицензией GPL.',
	'info_cours_edition' => 'В работе', # MODIF
	'info_creer_repertoire' => 'Создайте файл или папку с названием:',
	'info_creer_repertoire_2' => 'в подразделе <b>@repertoire@</b>, затем ',
	'info_creer_vignette' => 'автоматическое создание миниатюр изображений',
	'info_creerdansrubrique_non_autorise' => 'У вас недостаточно прав, чтобы создавать материалы в этом разделе',
	'info_deplier' => 'Откройте',
	'info_descriptif_nombre' => 'описание(я):',
	'info_description' => 'Описание:',
	'info_description_2' => 'Описание:',
	'info_dimension' => 'Размер:',
	'info_documents_nb' => '@nb@ файлов',
	'info_documents_un' => '1 файл',
	'info_ecire_message_prive' => 'Написать личное сообщение',
	'info_email_invalide' => 'Неправильный e-mail адрес',
	'info_en_cours_validation' => 'Ваши неопубликованные статьи',
	'info_en_ligne' => 'Сейчас on-line:',
	'info_envoyer_message_prive' => 'Отправить личное сообщение автору',
	'info_erreur_requete' => 'Ошибка в запросе:',
	'info_erreur_squelette2' => 'Файл шаблона <b>@fichier@</b> недоступен',
	'info_erreur_systeme' => 'Ошибка системы (errno @errsys@)',
	'info_erreur_systeme2' => 'Закончилось место на диске или повреждена база данных. <br />
<span style="color:red;">Попробуйте <a href=\'@script@\'>восстановить базу данных</a>
 или обратитесь к вашему хостинг-провайдеру.</span>',
	'info_fini' => 'Готово!',
	'info_format_image' => 'Формат, используемый для автоматического уменьшения изображений @gd_formats@.',
	'info_format_non_defini' => 'неопределенный формат',
	'info_grand_ecran' => 'Большой экран',
	'info_image_aide' => 'ПОМОЩЬ',
	'info_image_process_titre' => 'Как создавать миниатюры',
	'info_impossible_lire_page' => '<b>Ошибка!</b> Страницу <tt><html>@test_proxy@</html></tt> нельзя получить через прокси сервер',
	'info_installation_systeme_publication' => 'Установка SPIP ...',
	'info_installer_documents' => 'Вы можете разместить файлы в папку @upload@, и они будут добавлены автоматически.',
	'info_installer_ftp' => 'Вы можете переписать файлы по FTP в папку @upload@, чтобы использовать их в дальнейшей работе. ',
	'info_installer_images' => 'Вы можете добавлять изображения в форматах JPEG, GIF или PNG.',
	'info_installer_images_dossier' => 'Добавьте изображения в папку  @upload@ для использования их в этом меню.',
	'info_interface_complete' => 'полный интерфейс',
	'info_interface_simple' => 'Упрощенный интерфейс',
	'info_joindre_document_article' => 'Вы можете добавить к вашей статье документы ',
	'info_joindre_document_rubrique' => 'Вы можете добавить документы к этому разделу',
	'info_joindre_documents_article' => 'Вы можете прикрепить к вашей статье документы:',
	'info_l_article' => 'статья',
	'info_la_breve' => 'новость',
	'info_la_rubrique' => 'раздел',
	'info_langue_principale' => 'Главный язык сайта',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ px',
	'info_les_auteurs_1' => ' @les_auteurs@ ',
	'info_logo_format_interdit' => 'Разрешено использовать логотипы только в форматах @formats@.',
	'info_logo_max_poids' => 'Логотип должны быть меньше, чем @maxi@ (размер этого файла @actuel@).',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'СООБЩЕНИЕ',
	'info_message_supprime' => 'СООБЩЕНИЕ УДАЛЕНО',
	'info_messages_nb' => '@nb@ сообщений',
	'info_messages_un' => '1 сообщение',
	'info_mise_en_ligne' => 'Опубликовано:',
	'info_modification_parametres_securite' => 'изменить настройки безопасности',
	'info_mois_courant' => 'На протяжении месяца:',
	'info_mot_cle_ajoute' => 'Ключ был добавлен к',
	'info_multi_herit' => 'Язык по умолчанию',
	'info_multi_langues_soulignees' => 'Если название <u>языка подчеркнуто</u>, то это значит, что есть перевод административной части SPIP на этот язык. При выборе других языков все системные сообщения будут выводиться на основном языке сайта.',
	'info_multilinguisme' => 'Многоязычность',
	'info_nom_non_utilisateurs_connectes' => 'Не показывать меня в списке пользователей online.',
	'info_nom_utilisateurs_connectes' => 'Показывать меня в списке пользователей online.',
	'info_nombre_en_ligne' => 'Сейчас  на сайте:',
	'info_non_resultat' => 'Ничего не найдено по запросу «@cherche_mot@»',
	'info_non_utilisation_messagerie' => 'Система личных сообщений отключена на этом сайте.',
	'info_nouveau_message' => 'ПОЛУЧЕНО НОВОЕ СООБЩЕНИЕ',
	'info_nouveaux_messages' => 'У ВАС @total_messages@ НОВОЕ(ЫХ) СООБЩЕНИЕ(Й):',
	'info_numero_abbreviation' => '№',
	'info_obligatoire' => 'Обязательные поля',
	'info_pense_bete' => 'ЗАМЕТКА',
	'info_petit_ecran' => 'Маленький экран',
	'info_petition_close' => 'Петиция закрыта',
	'info_pixels' => 'пиксели',
	'info_plusieurs_mots_trouves' => 'По запросу «@cherche_mot@» были найдены такие ключи:',
	'info_portfolio_automatique' => 'Автоматизированное портфолио:',
	'info_premier_resultat' => '[@debut_limit@ из @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ из @total@]',
	'info_propose_1' => '[@nom_site_spip@] Предложенные: @titre@',
	'info_propose_2' => 'Статья предложена
-----------------',
	'info_propose_3' => 'Статья «@titre@» предложена для публикации.',
	'info_propose_4' => 'Вы приглашены для рецензирования. Выскажите свое мнение',
	'info_propose_5' => 'на связанном с этим форуме, расположенном по адресу:',
	'info_publie_01' => 'Статья «@titre@» была одобрена @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] ОПУБЛИКОВАНО: @titre@',
	'info_publie_2' => 'Статья опубликована
-----------------',
	'info_rechercher' => 'Поиск',
	'info_rechercher_02' => 'Поиск:',
	'info_remplacer_vignette' => 'Заменить миниатюру своим уменьшенным изображением:',
	'info_rubriques_nb' => '@nb@ раздела(ов)',
	'info_rubriques_un' => '1 раздел',
	'info_sans_titre_2' => 'без названия',
	'info_selectionner_fichier' => 'Вы можете выбрать файл из папки @upload@',
	'info_selectionner_fichier_2' => 'Выбрать файл:',
	'info_sites_nb' => '@nb@ сайтов',
	'info_sites_un' => '1 сайт',
	'info_supprimer_vignette' => 'удалить миниатюру',
	'info_symbole_bleu' => '<b>Синий</b> символ  указывает на <b>заметку</b> - сообщение для вашего личного использования.',
	'info_symbole_jaune' => '<b>Желтый</b> символ - <b> объявление всем редакторам </b>: объявление может редактировать любой администратор и его видят все редактора.',
	'info_symbole_vert' => '<b>Зеленый</b> символ - <b> переписка с другими пользователями </b> сайта.',
	'info_telecharger_nouveau_logo' => 'Загрузить новое лого:',
	'info_telecharger_ordinateur' => 'Загрузить с вашего компьютера:',
	'info_tous_resultats_enregistres' => '[все результаты записаны]',
	'info_tout_afficher' => 'Показать все',
	'info_travaux_texte' => 'Ведутся работы по настройке сайта, скоро мы начнем работу.',
	'info_travaux_titre' => 'Сайт еще не работает',
	'info_trop_resultat' => 'Слишком много результатов по запросу «@cherche_mot@»; пожалуйста, уточните запрос.',
	'info_utilisation_messagerie_interne' => 'Сервис внутренних приватных сообщений включен.',
	'info_valider_lien' => 'подтвердить ссылку',
	'info_verifier_image' => ', проверьте, что ваши изображения были переданы правильно.',
	'info_vignette_defaut' => 'Миниатюра по умолчанию',
	'info_vignette_personnalisee' => 'Ваша миниатюра (уменьшенное изображение)',
	'info_visite' => 'посещение:',
	'info_vos_rendez_vous' => 'Ваши будущие задачи',
	'infos_vos_pense_bete' => 'Ваши заметки',

	// L
	'label_ajout_id_rapide' => 'Быстрое добавление',
	'label_poids_fichier' => 'Размер',
	'lien_afficher_icones_seuls' => 'Показывать только иконки',
	'lien_afficher_texte_icones' => 'Показывать иконки и текст',
	'lien_afficher_texte_seul' => 'Показывать только текст',
	'lien_liberer' => 'версия',
	'lien_liberer_tous' => 'освободить эти статьи',
	'lien_nouvea_pense_bete' => 'НОВАЯ ЗАМЕТКА',
	'lien_nouveau_message' => 'НОВОЕ СООБЩЕНИЕ',
	'lien_nouvelle_annonce' => 'НОВОЕ ОБЪЯВЛЕНИЕ',
	'lien_petitions' => 'ПЕТИЦИЯ',
	'lien_popularite' => 'популярность: @popularite@%',
	'lien_racine_site' => 'КОРЕНЬ САЙТА',
	'lien_reessayer' => 'попробуйте еще раз',
	'lien_repondre_message' => 'Ответить на сообщение',
	'lien_supprimer' => 'удалить',
	'lien_tout_afficher' => 'Показать все',
	'lien_visite_site' => 'посетить этот сайт',
	'lien_visites' => '@visites@ посещений',
	'lien_voir_auteur' => 'Проверить автора',
	'ligne' => 'Линия',
	'login' => 'Подключение',
	'login_acces_prive' => 'доступ к административной части',
	'login_autre_identifiant' => 'изменить логин',
	'login_cookie_accepte' => 'Пожалуйста, настройте ваш браузер для приема cookies (по крайней мере для этого сайта).',
	'login_cookie_oblige' => 'В вашем браузере должны быть включены cookies.',
	'login_deconnexion_ok' => 'Вышел из системы.',
	'login_erreur_pass' => 'Пароль введен неправильно.',
	'login_espace_prive' => 'административная часть',
	'login_identifiant_inconnu' => 'Логин «@login@» неизвестен.',
	'login_login' => 'Логин:',
	'login_login2' => 'Логин или email:',
	'login_login_pass_incorrect' => '(Неправильный логин или пароль).',
	'login_motpasseoublie' => 'забыли пароль?',
	'login_non_securise' => 'Внимание, эта форма небезопасна! 
Если вы не хотите, чтобы ваш пароль был открыт для перехвата в сети, активизируйте Javascript в вашем браузере и ',
	'login_nouvelle_tentative' => 'Попробовать еще раз',
	'login_par_ici' => 'Вы зарегистрированы... вам сюда...',
	'login_pass2' => 'Пароль:',
	'login_preferez_refuser' => '<b>Если Вы хотите отказаться от cookies </b>, есть другой метод входа на сайт (менее безопасный):',
	'login_recharger' => 'перегрузить страницу',
	'login_rester_identifie' => 'Запомнить логин на несколько дней', # MODIF
	'login_retour_public' => 'На главную страницу сайта',
	'login_retour_site' => 'На главную страницу сайта',
	'login_retoursitepublic' => 'на главную страницу сайта',
	'login_sans_cookie' => 'Идентификация без cookie',
	'login_securise' => 'Безопасный вход',
	'login_sinscrire' => 'регистрация',
	'login_test_navigateur' => 'проверка браузера/(пере)подключения',
	'login_verifiez_navigateur' => '(проверьте, что ваш браузер не запоминает ваш пароль ...), ',

	// M
	'masquer_colonne' => 'Скрыть колонку',
	'masquer_trad' => 'скрыть перевод(ы)',
	'module_fichiers_langues' => 'Языковые файлы',

	// N
	'navigateur_pas_redirige' => 'Если ваш браузер не переходит автоматически, нажмите здесь, чтобы продолжить.',
	'numero' => 'Номер',

	// O
	'occurence' => 'Пример',
	'onglet_affacer_base' => 'Удалить базу данных',
	'onglet_auteur' => 'Автор',
	'onglet_contenu_site' => 'Содержание сайта',
	'onglet_evolution_visite_mod' => 'История посещений',
	'onglet_fonctions_avances' => 'Дополнительные настройки',
	'onglet_informations_personnelles' => 'Персональная информация',
	'onglet_interactivite' => 'Регистрация, рассылки',
	'onglet_messagerie' => 'Сообщения',
	'onglet_repartition_rubrique' => 'Посещения по разделам',
	'onglet_save_restaur_base' => 'Резервная копия/востановление базы данных',
	'onglet_vider_cache' => 'Очистить кеш',

	// P
	'pass_choix_pass' => 'Введите новый пароль:',
	'pass_erreur' => 'Ошибка',
	'pass_erreur_acces_refuse' => '<b>Ошибка:</b> у вас больше нет доступа к этому сайту.',
	'pass_erreur_code_inconnu' => '<b>Ошибка: </b> этот код не дает прав на доступ к этой части сайта.',
	'pass_erreur_non_enregistre' => '<b>Ошибка:</b> адрес <tt>@email_oubli@</tt> не зарегистрирован на этом сайте.',
	'pass_erreur_non_valide' => '<b>Ошибка:</b> e-mail <tt>@email_oubli@</tt> неправильный!',
	'pass_erreur_probleme_technique' => '<b>Ошибка:</b> это письмо не может быть отправлено по техническим причинам.',
	'pass_espace_prive_bla' => 'Вы можете войти в административную (приватную) часть сайта 
после регистрации. После регистрации 
вы можете создавать статьи 
и участвовать во всех обсуждениях.',
	'pass_forum_bla' => 'Вы отправили запрос для  участия в 
форуме, который доступен только для зарегистрированных пользователей.',
	'pass_indiquez_cidessous' => 'Введите ниже адрес электронной почты, который вы использовали для регистрации. Вам будет отправлено письмо с дальнейшими инструкциями.',
	'pass_mail_passcookie' => '(это письмо отправлено автоматически)

Для того, что бы восстановить ваш пароль для входа на сайт @nom_site_spip@ (@adresse_site@) 

перейдите по следующей ссылке: 
    @sendcookie@

Введите новый пароль и попробуйте снова зайти на сайт 


(this is an automated message)

To retrieve your access to the site
@nom_site_spip@ (@adresse_site@)

Please go to the following address:
    @sendcookie@

You can then enter a new password
and connect again to the site.
',
	'pass_mot_oublie' => 'забытый пароль',
	'pass_nouveau_enregistre' => 'Новый пароль сохранен.',
	'pass_nouveau_pass' => 'Новый пароль',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Забытый пароль',
	'pass_procedure_changer' => 'Чтобы изменить пароль введите, пожалуйста, e-mail, который вы указали при регистрации.',
	'pass_quitter_fenetre' => 'Закрыть окно',
	'pass_rappel_login' => 'Напоминаем: ваш  логин «@login@».',
	'pass_recevoir_mail' => 'Вы получите письмо, в котором будут дальнейшие инструкции по регистрации на сайте.', # MODIF
	'pass_retour_public' => 'Назад к основному сайту',
	'pass_rien_a_faire_ici' => 'Нечего здесь делать',
	'pass_vousinscrire' => 'Регистрация с сайта',
	'precedent' => 'предыдущий',
	'previsualisation' => 'Предварительный просмотр',
	'previsualiser' => 'Предварительный просмотр',

	// R
	'retour' => 'Вернуться',

	// S
	'spip_conforme_dtd' => 'SPIP обнаружил, что данная страница соответствует своему DOCTYPE:',
	'squelette' => 'шаблон',
	'squelette_inclus_ligne' => 'включенный шаблон, строка',
	'squelette_ligne' => 'шаблон, строка',
	'stats_visites_et_popularite' => '@visites@ посещений; популярность: @popularite@',
	'suivant' => 'следующий',

	// T
	'taille_go' => '@taille@ Гб',
	'taille_ko' => '@taille@ кб',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Когда вы освоитесь с интерфейсом, нажмите «',
	'texte_actualite_site_2' => 'полный интерфейс',
	'texte_actualite_site_3' => '», который сделает больше функций доступными.',
	'texte_creation_automatique_vignette' => 'Для каждого файла (в формате @gd_formats@), добавленного через форму, автоматически будет создана уменьшенная версия  - миниатюра (максимальный размер @taille_preview@ пикселей).',
	'texte_documents_associes' => 'Следующие документы связаны со статьей, 
    но они не были 
    вставлены. На сайте они могут отображаться как прикрепленные документы (в зависимости от дизайна).',
	'texte_erreur_mise_niveau_base' => 'Ошибка базы данных в процессе апгрейда.  Изображение <b> @fichier@ </b> нельзя  передать (статья @id_article@). <p> Еще раз нажмите на ссылку, повторите процедуру апгрейда и удостоверьтесь, что изображения есть в статьях.',
	'texte_erreur_visiteur' => 'Вы пробовали получить доступ к административной части сайта с использованием логина, который не имеет достаточно прав для такой операции.',
	'texte_inc_auth_1' => 'Вы ввели логин <b>@auth_login@</b>. Такого пользователя нет в базе данных. 
Пробуйте еще раз',
	'texte_inc_auth_2' => '(пере)подключиться',
	'texte_inc_auth_3' => ', выйдите и перезагрузите ваш браузер в случае необходимости.',
	'texte_inc_config' => 'Изменение настроек сайта очень сильно влияет на его работу.
Настоятельно рекомендуем менять настройки только в том случае, если вы четко представляете,
 какие изменения это повлечет.
<b>Вы можете запросить консультацию у разработчика Вашего сайта по настройкам системы.</b>',
	'texte_inc_meta_1' => 'Система вызвала  ошибку при попытке записи в файл <code>@fichier@</code>. Обратитесь к администратору сайта, чтобы',
	'texte_inc_meta_2' => 'проверить права доступа на запись',
	'texte_inc_meta_3' => ' в папке <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'готовится',
	'texte_statut_poubelle' => 'удалена',
	'texte_statut_propose_evaluation' => 'утверждается',
	'texte_statut_publie' => 'опубликована',
	'texte_statut_refuse' => 'отклонена',
	'titre_ajouter_mot_cle' => 'ДОБАВИТЬ КЛЮЧ:',
	'titre_cadre_raccourcis' => 'БЫСТРЫЙ ПЕРЕХОД:',
	'titre_changer_couleur_interface' => 'Изменение цвета интерфейса',
	'titre_image_admin_article' => 'Вы можете администрировать эту статью ',
	'titre_image_administrateur' => 'Администратор',
	'titre_image_aide' => 'Помощь',
	'titre_image_auteur_supprime' => 'Автор удален',
	'titre_image_redacteur' => 'Редактор без доступа',
	'titre_image_redacteur_02' => 'Редактор',
	'titre_image_selecteur' => 'Показать список',
	'titre_image_visiteur' => 'Посетитель',
	'titre_joindre_document' => 'ПРИЛОЖИТЬ ДОКУМЕНТ',
	'titre_mots_cles' => 'КЛЮЧИ',
	'titre_probleme_technique' => 'Внимание: невозможно подключиться к SQL серверу, сайт не работает. Спасибо за понимание, мы постараемся оперативно решить проблему.',
	'titre_publier_document' => 'ДОБАВИТЬ ДОКУМЕНТ К РАЗДЕЛУ',
	'titre_signatures_attente' => 'Подписи ожидают одобрения',
	'titre_signatures_confirmees' => 'Подписи подтверждены',
	'titre_statistiques' => 'Статистика сайта',
	'titre_titre_document' => 'Название документа:',
	'todo' => 'сделать',
	'trad_definir_reference' => 'Выберите «@titre@» как источник перевода',
	'trad_reference' => '(источник для переводов)',

	// Z
	'zbug_balise_b_aval' => ': B tag too late in loop',
	'zbug_balise_inexistante' => 'Тег #@balise@ некорректно указан для @from@ ',
	'zbug_balise_sans_argument' => 'Не хватает аргумента в теге @balise@',
	'zbug_boucle' => 'цикл (boucle)',
	'zbug_boucle_recursive_undef' => 'не определен рекурсивный цикл (boucle): @nom@',
	'zbug_calcul' => 'вычисления',
	'zbug_champ_hors_boucle' => 'Поле @champ@ находится вне цикла (boucle)',
	'zbug_champ_hors_motif' => 'Поле @champ@ находится вне контекста @motif@',
	'zbug_code' => 'код ',
	'zbug_critere_inconnu' => 'Неизвестный критерий @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} таблица без первичного ключа ',
	'zbug_distant_interdit' => 'Внешние данные запрещены',
	'zbug_doublon_table_sans_cle_primaire' => 'Дубликаты записей в таблице, не имеющей простого первичного ключа',
	'zbug_doublon_table_sans_index' => 'Дубликаты записей в таблице без индекса',
	'zbug_erreur_boucle_double' => 'Цикл @id@ указан дважды в одном шаблоне',
	'zbug_erreur_boucle_fermant' => 'Цикл @id@: отсутствует закрывающий тег',
	'zbug_erreur_boucle_syntaxe' => 'Синтаксическая ошибка в цикле  @id@',
	'zbug_erreur_compilation' => 'Ошибка компиляции',
	'zbug_erreur_execution_page' => 'Ошибка исполнения',
	'zbug_erreur_filtre' => 'Неопределенный фильтр @filtre@',
	'zbug_erreur_meme_parent' => 'Критерий {meme_parent} может использоваться только в циклах   (FORUMS) и (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Ошибка(и) в шаблоне',
	'zbug_hors_compilation' => 'Не скомпилировано',
	'zbug_info_erreur_squelette' => 'Ошибка на сайте',
	'zbug_inversion_ordre_inexistant' => 'Реверсия несуществующего порядка',
	'zbug_pagination_sans_critere' => 'Используется тег #PAGINATION но в цикле не указан критерий  {pagination} или тег используется в рекурсивном цикле.',
	'zbug_parametres_inclus_incorrects' => 'Неверный включающий параметр: @param@',
	'zbug_profile' => 'Время вычисления: @time@',
	'zbug_resultat' => 'результат',
	'zbug_serveur_indefini' => 'Не определен SQL сервер',
	'zbug_statistiques' => 'Информация о SQL запросах (отсортировано по времени выполнения) ',
	'zbug_table_inconnue' => 'Неизвестная SQL таблица «@table@»',
	'zxml_connus_attributs' => 'известные атрибуты',
	'zxml_de' => 'из',
	'zxml_inconnu_attribut' => 'неизвестный атрибут',
	'zxml_inconnu_balise' => 'неизвестный тег',
	'zxml_inconnu_entite' => 'неизвестная запись',
	'zxml_inconnu_id' => 'неизвестный ID',
	'zxml_mais_de' => 'но из',
	'zxml_non_conforme' => 'не соответствует принципу',
	'zxml_non_fils' => 'не является дочерним по отношению к',
	'zxml_nonvide_balise' => 'тег не пуст',
	'zxml_obligatoire_attribut' => 'требуется атрибут, отсутствующий в',
	'zxml_succession_fils_incorrecte' => 'неверное дочернее наследование',
	'zxml_survoler' => 'чтобы увидеть правильные, наведите курсор',
	'zxml_valeur_attribut' => 'значение атрибута',
	'zxml_vide_balise' => 'пустой тег',
	'zxml_vu' => 'уже просматривалось'
);
